==> anwiba-spatial-data-ckan-1.0.185-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/License.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class License
    extends Named
{

    private String id = null;
    private String url = null;
    private String status = null;
    private String maintainer = null;
    private String family = null;
    private String license_id = null;
    private String license_url = null;
    private String other = null;
    private String attribution_text = null;
    private Boolean is_generic = Boolean.valueOf(false);
    private Boolean domain_data = Boolean.valueOf(false);
    private Boolean domain_content = Boolean.valueOf(false);
    private String od_conformance = null;
    private Boolean is_okd_compliant = Boolean.valueOf(false);
    private Boolean domain_software = Boolean.valueOf(false);
    private String osd_conformance = null;
    private Boolean is_osi_compliant = Boolean.valueOf(false);
    private Boolean is_free_to_use = Boolean.valueOf(false);
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("url")
    public void setUrl(final String url) {
        this.url = url;
    }

    @JsonProperty("url")
    public String getUrl() {
        return this.url;
    }

    @JsonProperty("status")
    public void setStatus(final String status) {
        this.status = status;
    }

    @JsonProperty("status")
    public String getStatus() {
        return this.status;
    }

    @JsonProperty("maintainer")
    public void setMaintainer(final String maintainer) {
        this.maintainer = maintainer;
    }

    @JsonProperty("maintainer")
    public String getMaintainer() {
        return this.maintainer;
    }

    @JsonProperty("family")
    public void setFamily(final String family) {
        this.family = family;
    }

    @JsonProperty("family")
    public String getFamily() {
        return this.family;
    }

    @JsonProperty("license_id")
    public void setLicense_id(final String license_id) {
        this.license_id = license_id;
    }

    @JsonProperty("license_id")
    public String getLicense_id() {
        return this.license_id;
    }

    @JsonProperty("license_url")
    public void setLicense_url(final String license_url) {
        this.license_url = license_url;
    }

    @JsonProperty("license_url")
    public String getLicense_url() {
        return this.license_url;
    }

    @JsonProperty("other")
    public void setOther(final String other) {
        this.other = other;
    }

    @JsonProperty("other")
    public String getOther() {
        return this.other;
    }

    @JsonProperty("attribution_text")
    public void setAttribution_text(final String attribution_text) {
        this.attribution_text = attribution_text;
    }

    @JsonProperty("attribution_text")
    public String getAttribution_text() {
        return this.attribution_text;
    }

    @JsonProperty("is_generic")
    public void setIs_generic(final Boolean is_generic) {
        this.is_generic = is_generic;
    }

    @JsonProperty("is_generic")
    public Boolean is_generic() {
        return this.is_generic;
    }

    @JsonProperty("domain_data")
    public void setDomain_data(final Boolean domain_data) {
        this.domain_data = domain_data;
    }

    @JsonProperty("domain_data")
    public Boolean isDomain_data() {
        return this.domain_data;
    }

    @JsonProperty("domain_content")
    public void setDomain_content(final Boolean domain_content) {
        this.domain_content = domain_content;
    }

    @JsonProperty("domain_content")
    public Boolean isDomain_content() {
        return this.domain_content;
    }

    @JsonProperty("od_conformance")
    public void setOd_conformance(final String od_conformance) {
        this.od_conformance = od_conformance;
    }

    @JsonProperty("od_conformance")
    public String getOd_conformance() {
        return this.od_conformance;
    }

    @JsonProperty("is_okd_compliant")
    public void setIs_okd_compliant(final Boolean is_okd_compliant) {
        this.is_okd_compliant = is_okd_compliant;
    }

    @JsonProperty("is_okd_compliant")
    public Boolean is_okd_compliant() {
        return this.is_okd_compliant;
    }

    @JsonProperty("domain_software")
    public void setDomain_software(final Boolean domain_software) {
        this.domain_software = domain_software;
    }

    @JsonProperty("domain_software")
    public Boolean isDomain_software() {
        return this.domain_software;
    }

    @JsonProperty("osd_conformance")
    public void setOsd_conformance(final String osd_conformance) {
        this.osd_conformance = osd_conformance;
    }

    @JsonProperty("osd_conformance")
    public String getOsd_conformance() {
        return this.osd_conformance;
    }

    @JsonProperty("is_osi_compliant")
    public void setIs_osi_compliant(final Boolean is_osi_compliant) {
        this.is_osi_compliant = is_osi_compliant;
    }

    @JsonProperty("is_osi_compliant")
    public Boolean is_osi_compliant() {
        return this.is_osi_compliant;
    }

    @JsonProperty("is_free_to_use")
    public void setIs_free_to_use(final Boolean is_free_to_use) {
        this.is_free_to_use = is_free_to_use;
    }

    @JsonProperty("is_free_to_use")
    public Boolean is_free_to_use() {
        return this.is_free_to_use;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}

==> anwiba-spatial-data-ckan-1.2.50-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/License.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;

public class License
    extends Named
{

    private String id = null;
    private String url = null;
    private String status = null;
    private String maintainer = null;
    private String family = null;
    private String license_id = null;
    private String license_url = null;
    private String other = null;
    private String attribution_text = null;
    private Boolean is_generic = Boolean.valueOf(false);
    private Boolean domain_data = Boolean.valueOf(false);
    private Boolean domain_content = Boolean.valueOf(false);
    private String od_conformance = null;
    private Boolean is_okd_compliant = Boolean.valueOf(false);
    private Boolean domain_software = Boolean.valueOf(false);
    private String osd_conformance = null;
    private Boolean is_osi_compliant = Boolean.valueOf(false);
    private Boolean is_free_to_use = Boolean.valueOf(false);
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<>();

    @JsonProperty("id")
    public void setId(final String id) {
        this.id = id;
    }

    @JsonProperty("id")
    public String getId() {
        return this.id;
    }

    @JsonProperty("url")
    public void setUrl(final String url) {
        this.url = url;
    }

    @JsonProperty("url")
    public String getUrl() {
        return this.url;
    }

    @JsonProperty("status")
    public void setStatus(final String status) {
        this.status = status;
    }

    @JsonProperty("status")
    public String getStatus() {
        return this.status;
    }

    @JsonProperty("maintainer")
    public void setMaintainer(final String maintainer) {
        this.maintainer = maintainer;
    }

    @JsonProperty("maintainer")
    public String getMaintainer() {
        return this.maintainer;
    }

    @JsonProperty("family")
    public void setFamily(final String family) {
        this.family = family;
    }

    @JsonProperty("family")
    public String getFamily() {
        return this.family;
    }

    @JsonProperty("license_id")
    public void setLicense_id(final String license_id) {
        this.license_id = license_id;
    }

    @JsonProperty("license_id")
    public String getLicense_id() {
        return this.license_id;
    }

    @JsonProperty("license_url")
    public void setLicense_url(final String license_url) {
        this.license_url = license_url;
    }

    @JsonProperty("license_url")
    public String getLicense_url() {
        return this.license_url;
    }

    @JsonProperty("other")
    public void setOther(final String other) {
        this.other = other;
    }

    @JsonProperty("other")
    public String getOther() {
        return this.other;
    }

    @JsonProperty("attribution_text")
    public void setAttribution_text(final String attribution_text) {
        this.attribution_text = attribution_text;
    }

    @JsonProperty("attribution_text")
    public String getAttribution_text() {
        return this.attribution_text;
    }

    @JsonProperty("is_generic")
    public void setIs_generic(final Boolean is_generic) {
        this.is_generic = is_generic;
    }

    @JsonProperty("is_generic")
    public Boolean is_generic() {
        return this.is_generic;
    }

    @JsonProperty("domain_data")
    public void setDomain_data(final Boolean domain_data) {
        this.domain_data = domain_data;
    }

    @JsonProperty("domain_data")
    public Boolean isDomain_data() {
        return this.domain_data;
    }

    @JsonProperty("domain_content")
    public void setDomain_content(final Boolean domain_content) {
        this.domain_content = domain_content;
    }

    @JsonProperty("domain_content")
    public Boolean isDomain_content() {
        return this.domain_content;
    }

    @JsonProperty("od_conformance")
    public void setOd_conformance(final String od_conformance) {
        this.od_conformance = od_conformance;
    }

    @JsonProperty("od_conformance")
    public String getOd_conformance() {
        return this.od_conformance;
    }

    @JsonProperty("is_okd_compliant")
    public void setIs_okd_compliant(final Boolean is_okd_compliant) {
        this.is_okd_compliant = is_okd_compliant;
    }

    @JsonProperty("is_okd_compliant")
    public Boolean is_okd_compliant() {
        return this.is_okd_compliant;
    }

    @JsonProperty("domain_software")
    public void setDomain_software(final Boolean domain_software) {
        this.domain_software = domain_software;
    }

    @JsonProperty("domain_software")
    public Boolean isDomain_software() {
        return this.domain_software;
    }

    @JsonProperty("osd_conformance")
    public void setOsd_conformance(final String osd_conformance) {
        this.osd_conformance = osd_conformance;
    }

    @JsonProperty("osd_conformance")
    public String getOsd_conformance() {
        return this.osd_conformance;
    }

    @JsonProperty("is_osi_compliant")
    public void setIs_osi_compliant(final Boolean is_osi_compliant) {
        this.is_osi_compliant = is_osi_compliant;
    }

    @JsonProperty("is_osi_compliant")
    public Boolean is_osi_compliant() {
        return this.is_osi_compliant;
    }

    @JsonProperty("is_free_to_use")
    public void setIs_free_to_use(final Boolean is_free_to_use) {
        this.is_free_to_use = is_free_to_use;
    }

    @JsonProperty("is_free_to_use")
    public Boolean is_free_to_use() {
        return this.is_free_to_use;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
